@@ -27,7 +27,7 @@ class ClientProtocol(Protocol):
         base_data: Dict[str, str],
         optional_fields: Dict[str, Optional[str]],
         signature_algorithm: str,
-    ) -> Element[str]:
+    ) -> Element:
         """Build XML and signature."""
         ...
 
