@@ -1,5 +1,6 @@
 """Invoice operations for RoboKassa API."""
 
+import json
 from decimal import Decimal
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, cast
 
@@ -101,8 +102,6 @@ class InvoiceMixin:
             elif isinstance(receipt, dict):
                 receipt_model = Receipt.from_dict(receipt)
             elif isinstance(receipt, str):
-                import json
-
                 receipt_dict = json.loads(receipt)
                 receipt_model = Receipt.from_dict(receipt_dict)
             else:
@@ -147,10 +146,11 @@ class InvoiceMixin:
         secret_key = f"{client.merchant_login}:{client.password1}"
         jwt_token = create_jwt_token(payload, secret_key, signature_algorithm)
 
-        # Send request (JWT token wrapped in JSON object with "request" field)
+        # Send request (JWT token as string in request body, not wrapped in JSON)
+        # According to RoboKassa docs: "Запрос представляет собой JWT-строку, которая передается в теле HTTP запроса"
         response = await client._post(
             f"{INVOICE_API_BASE_URL}/CreateInvoice",
-            json={"request": jwt_token},
+            data=jwt_token.encode("utf-8"),
             headers={"Content-Type": "application/json"},
         )
         async with response:
@@ -210,10 +210,11 @@ class InvoiceMixin:
         secret_key = f"{client.merchant_login}:{client.password1}"
         jwt_token = create_jwt_token(payload, secret_key, signature_algorithm)
 
-        # Send request (JWT token wrapped in JSON object with "request" field)
+        # Send request (JWT token as string in request body, not wrapped in JSON)
+        # According to RoboKassa docs: "Запрос представляет собой JWT-строку, которая передается в теле HTTP запроса"
         response = await client._post(
             f"{INVOICE_API_BASE_URL}/DeactivateInvoice",
-            json={"request": jwt_token},
+            data=jwt_token.encode("utf-8"),
             headers={"Content-Type": "application/json"},
         )
         async with response:
@@ -296,10 +297,11 @@ class InvoiceMixin:
         secret_key = f"{client.merchant_login}:{client.password1}"
         jwt_token = create_jwt_token(payload, secret_key, signature_algorithm)
 
-        # Send request (JWT token wrapped in JSON object with "request" field)
+        # Send request (JWT token as string in request body, not wrapped in JSON)
+        # According to RoboKassa docs: "Запрос представляет собой JWT-строку, которая передается в теле HTTP запроса"
         response = await client._post(
             f"{INVOICE_API_BASE_URL}/GetInvoiceInformationList",
-            json={"request": jwt_token},
+            data=jwt_token.encode("utf-8"),
             headers={"Content-Type": "application/json"},
         )
         async with response:
