@@ -1,7 +1,8 @@
 """Models for aiorobokassa."""
 
+from aiorobokassa.models.receipt import Receipt, ReceiptItem
 from aiorobokassa.models.requests import (
-    InvoiceRequest,
+    InvoiceItem,
     PaymentRequest,
     RefundRequest,
     ResultURLNotification,
@@ -12,6 +13,8 @@ __all__ = [
     "PaymentRequest",
     "ResultURLNotification",
     "SuccessURLNotification",
-    "InvoiceRequest",
+    "InvoiceItem",
     "RefundRequest",
+    "Receipt",
+    "ReceiptItem",
 ]
